@@ -1,3 +1,3 @@
 from .bmi import BMI, calculate_bmi
-from .egfr import calculate_egfr, eGFR
+from .egfr import EgfrCkdEpi, EgfrCockcroftGault, egfr_percent_change
 from .exceptions import CalculatorError
