@@ -1,3 +1,6 @@
 from .bmi_form_validator_mixin import BmiFormValidatorMixin
-from .egfr_form_validator_mixin import EgfrFormValidatorMixin
+from .egfr_form_validator_mixins import (
+    EgfrCkdEpiFormValidatorMixin,
+    EgfrCockcroftGaultFormValidatorMixin,
+)
 from .reportables_form_validator_mixin import ReportablesFormValidatorMixin
